#include <WiFi.h>
#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_ADXL343.h>

// Wi-Fi credentials
const char* ssid = "DavidPhone";        // Replace with your Wi-Fi SSID
const char* password = "dpchotspot"; // Replace with your Wi-Fi password

WiFiServer server(80); // Start a TCP server on port 80

// Create an instance of the ADXL343 sensor
Adafruit_ADXL343 accel = Adafruit_ADXL343(12345);

// Variables for timing
unsigned long lastSendTime = 0; // Last time data was sent
const int sendInterval = 1;     // Interval in milliseconds for ~1000 Hz

void setup() {
  Serial.begin(115200);
  while (!Serial);

  // Initialize Wi-Fi
  Serial.print("Connecting to Wi-Fi");
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("\nWi-Fi connected.");
  Serial.print("IP Address: ");
  Serial.println(WiFi.localIP());

  // Start the TCP server
  server.begin();
  Serial.println("Server started. Waiting for clients...");

  // Initialize the sensor
  if (!accel.begin()) {
    Serial.println("Ooops, no ADXL343 detected ... Check your wiring!");
    while (1);
  }

  // Set the range for the accelerometer
  accel.setRange(ADXL343_RANGE_16_G);
}

void loop() {
  // Check for new client connections
  WiFiClient client = server.available();

  if (client) {
    Serial.println("Client connected.");

    // Send data to the client while it's connected
    while (client.connected()) {
      // Only send data at the specified interval
      unsigned long currentTime = millis();
      if (currentTime - lastSendTime >= sendInterval) {
        lastSendTime = currentTime;

        // Get a new sensor event
        sensors_event_t event;
        accel.getEvent(&event);

        // Format accelerometer data as a string
        String data = "X: " + String(event.acceleration.x, 3) +
                      " Y: " + String(event.acceleration.y, 3) +
                      " Z: " + String(event.acceleration.z, 3) + "\n";

        // Send data to the client
        client.print(data);
        Serial.print("Sent to client: ");
        Serial.print(data);
      }
    }

    // Close the connection when the client disconnects
    client.stop();
    Serial.println("Client disconnected.");
  }
}
